@@ -38,8 +38,12 @@ def hash_log_secrets(log, secrets):
 
 def rosa_login(env, token, aws_region, allowed_commands=None):
     _allowed_commands = allowed_commands or parse_help()
+    if is_logged_in(allowed_commands=_allowed_commands, aws_region=aws_region):
+        LOGGER.info(f"Already logged in to {env} [region: {aws_region}].")
+        return
+
     build_execute_command(
-        command=f"login {f'--env={env}' if env else ''} --token={token}",
+        command=f"login f'--env={env} --token={token}",
         allowed_commands=_allowed_commands,
         aws_region=aws_region,
     )
@@ -314,15 +318,15 @@ def execute(
             ocm_env = ocm_client.api_client.configuration.host
             token = ocm_client.api_client.token
 
-        rosa_login(
-            env=ocm_env,
-            token=token,
-            aws_region=aws_region,
-            allowed_commands=_allowed_commands,
-        )
-
         # If running on openshift-ci we need to change $HOME to /tmp
         if os.environ.get("OPENSHIFT_CI") == "true":
+            rosa_login(
+                env=ocm_env,
+                token=token,
+                aws_region=aws_region,
+                allowed_commands=_allowed_commands,
+            )
+
             with change_home_environment():
                 return build_execute_command(
                     command=command,
@@ -330,6 +334,12 @@ def execute(
                     aws_region=aws_region,
                 )
         else:
+            rosa_login(
+                env=ocm_env,
+                token=token,
+                aws_region=aws_region,
+                allowed_commands=_allowed_commands,
+            )
             return build_execute_command(
                 command=command,
                 allowed_commands=_allowed_commands,
